var globals_vars =
[
    [ "a", "globals_vars.html", null ],
    [ "b", "globals_vars_b.html", null ],
    [ "c", "globals_vars_c.html", null ],
    [ "d", "globals_vars_d.html", null ],
    [ "e", "globals_vars_e.html", null ],
    [ "f", "globals_vars_f.html", null ],
    [ "h", "globals_vars_h.html", null ],
    [ "i", "globals_vars_i.html", null ],
    [ "l", "globals_vars_l.html", null ],
    [ "m", "globals_vars_m.html", null ],
    [ "p", "globals_vars_p.html", null ],
    [ "q", "globals_vars_q.html", null ],
    [ "r", "globals_vars_r.html", null ],
    [ "s", "globals_vars_s.html", null ],
    [ "u", "globals_vars_u.html", null ],
    [ "y", "globals_vars_y.html", null ]
];